% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/sce_to_ve.R
\name{sce_to_ve}
\alias{sce_to_ve}
\title{Convert a SCE object to a VE one}
\usage{
sce_to_ve(sce = fetch_data("sce"), bfc = BiocFileCache::BiocFileCache())
}
\arguments{
\item{sce}{Defaults to the output of
\code{fetch_data(type = 'sce')}. This is a
\linkS4class{SingleCellExperiment}
object with the spot-level Visium data and information required for
visualizing the histology. See \code{\link[=fetch_data]{fetch_data()}} for more details.}

\item{bfc}{A \code{BiocFileCache} object
\link[BiocFileCache:BiocFileCache-class]{BiocFileCache-class}. Used when
\code{eh} is not available.}
}
\value{
A a
\link[SpatialExperiment:VisiumExperiment]{VisiumExperiment-class} object
with some customization for our data. See \code{update_scaleFactors()} for
more details.
}
\description{
This function converts a spot-level
\link[SingleCellExperiment:SingleCellExperiment]{SingleCellExperiment-class}
(SCE) object as generated by \code{fetch_data()} to a
\link[SpatialExperiment:VisiumExperiment]{VisiumExperiment-class} (VE)
object.
}
\details{
Note that the resulting object is a bit more complex than a regular VE
because it contains the data for multiple images. Also, the VE validity
code checks that the images files exist locally instead of being
available remotely through a URL. Thus, we decided to download the images
the moment the VE object is created. To deal with the fact that we have
multiple images, we implemented the function \code{update_scaleFactors()} and
\code{read_image()} which is used in the example of \code{geom_plot()}.
}
\examples{

if (enough_ram()) {
    ## Download the sce data
    sce <- fetch_data("sce")
    ## Transform it to a VisiumExperiment object
    ve <- sce_to_ve(sce)
}
}
\seealso{
Other VisiumExperiment-related functions: 
\code{\link{read_image}()},
\code{\link{ve_image_colData}()}
}
\author{
Brenda Pardo, Leonardo Collado-Torres
}
\concept{VisiumExperiment-related functions}
